NamedTemplateCaptureVisionRequest class
A request that passes templateName unchanged to CaptureVisionRouter.
- Inheritance
-
- Object
- CaptureVisionRequest
- NamedTemplateCaptureVisionRequest
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateName → String
-
The exact, case-sensitive name declared in
CaptureVisionTemplates.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited